pub fn print_tree(
repo: &Repository,
tree_oid: Oid,
format: OutputFormat,
) -> Result<(), Box<dyn Error>>Expand description
Print a tree according to the requested output format.
pub fn print_tree(
repo: &Repository,
tree_oid: Oid,
format: OutputFormat,
) -> Result<(), Box<dyn Error>>Print a tree according to the requested output format.